/**
 * 导出 mixins、插件和组件，供外部使用
 *
 * 该文件用于整合项目中的全局混入（mixins）、插件（plugins）和组件（components），
 * 并通过 export 提供具名导出，同时提供一个默认导出对象，方便在 Vue 项目中统一引入。
 */

// 引入全局混入逻辑
import { checkToken } from "./mixins/index.js";

// 引入插件安装逻辑（如 Vue.use(...) 的封装）
import setupPlugins from "./plugin/index.js";

// 引入自定义组件集合
import {
  BrowserTypePrompt,
  ExpireModel,
  RichTextEditor,
  RichTextOption,
} from "./components/index.js";

// 引入登录加密功能
import { loginEncrypt } from "./func/loginEncryption/index.js";

// 将混入和插件安装函数作为命名导出，便于按需使用
export {
  loginEncrypt,
  checkToken,
  BrowserTypePrompt,
  ExpireModel,
  setupPlugins,
};

// 默认导出所有模块，可用于 Vue 应用的全局注册或配置
export default {
  mixins: { checkToken },
  components: {
    BrowserTypePrompt,
    ExpireModel,
    RichText: {
      Editor: RichTextEditor,
      initOption: RichTextOption,
    },
  },
  setupPlugins,
  func: { loginEncrypt },
};

// import { loginEncrypt } from 'xxxxxtollkit
