export default {
  name: "ToolkitMixCheckToken",
  data() {
    return {
      toolkit_mix_Timer: null,
    };
  },
  created() {
    this.toolkit_mix_checkToken();
  },
  beforeDestroy() {
    if (this.toolkit_mix_Timer) {
      clearInterval(this.toolkit_mix_Timer);
      this.toolkit_mix_Timer = null;
    }
  },
  methods: {
    /** 检查检测token状态
     * @param { url, token, interval } opt  interval 默认30s 单位ms
     */
    toolkit_mix_checkToken(opt) {
      const {
        url = "/auth/token/check_token",
        token,
        interval = 1000 * 30,
      } = opt || {};
      try {
        const tokenVal = token || this.$store.getters["user/token"];
        if (!tokenVal) {
          return console.warn(
            `jfcloud-front-toolkit/toolkit_mix_checkToken: 无法获取token：${
              tokenVal + ""
            }`
          );
        }
        if (!this.$http) {
          return console.warn(
            `jfcloud-front-toolkit/toolkit_mix_checkToken: this.$http不存在请手动重写toolkit_mix_checkToken`
          );
        }
        this.toolkit_mix_Timer = setInterval(() => {
          this.$http({
            url: url,
            method: "get",
            params: { token: tokenVal },
          });
        }, interval);
      } catch (e) {
        return console.error(
          `jfcloud-front-toolkit/toolkit_mix_checkToken: ${e}`
        );
      }
    },
  },
};
